# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class PatientDischargeStatusCode(enum.StrEnum):
    C_01 = "01"
    """
    DISCHARGED TO HOME OR SELF CARE (ROUTINE DISCHARGE)
    """

    C_02 = "02"
    """
    DISCHARGED/TRANSFERRED TO A SHORT-TERM GENERAL HOSPITAL FOR INPATIENT CARE
    """

    C_03 = "03"
    """
    DISCHARGED/TRANSFERRED TO SKILLED NURSING FACILITY (SNF) WITH MEDICARE CERTIFICATION IN ANTICIPATION OF SKILLED CARE
    """

    C_04 = "04"
    """
    DISCHARGED/TRANSFERRED TO A FACILITY THAT PROVIDES CUSTODIAL OR SUPPORTIVE CARE
    """

    C_05 = "05"
    """
    DISCHARGED/TRANSFERRED TO A DESIGNATED CANCER CENTER OR CHILDREN'S HOSPITAL
    """

    C_06 = "06"
    """
    DISCHARGED/TRANSFERRED TO HOME UNDER CARE OF AN ORGANIZED HOME HEALTH SERVICE ORGANIZATION IN ANTICIPATION OF COVERED SKILLED CARE
    """

    C_07 = "07"
    """
    LEFT AGAINST MEDICAL ADVICE OR DISCONTINUED CARE
    """

    C_09 = "09"
    """
    ADMITTED AS AN INPATIENT TO THIS HOSPITAL
    """

    C_20 = "20"
    """
    EXPIRED(A)
    """

    C_21 = "21"
    """
    DISCHARGED/TRANSFERRED TO COURT/LAW ENFORCEMENT
    """

    C_30 = "30"
    """
    STILL PATIENT
    """

    C_40 = "40"
    """
    EXPIRED AT HOME(A)
    """

    C_41 = "41"
    """
    EXPIRED IN A MEDICAL FACILITY A) (E.G. HOSPITAL, SNF, ICF, OR FREE STANDING HOSPICE)
    """

    C_42 = "42"
    """
    EXPIRED - PLACE UNKNOWN A)
    """

    C_43 = "43"
    """
    DISCHARGED/TRANSFERRED TO A FEDERAL HEALTH CARE FACILITY
    """

    C_50 = "50"
    """
    HOSPICE - HOME
    """

    C_51 = "51"
    """
    HOSPICE - MEDICAL FACILITY (CERTIFIED) PROVIDING HOSPICE LEVEL OF CARE
    """

    C_61 = "61"
    """
    DISCHARGED/TRANSFERRED TO A HOSPITAL-BASED MEDICARE APPROVED SWING BED
    """

    C_62 = "62"
    """
    DISCHARGED/TRANSFERRED TO AN INPATIENT REHABILITATION FACILITY (IRF) INCLUDING REHABILITATION DISTINCT PART UNITS OF A HOSPITAL
    """

    C_63 = "63"
    """
    DISCHARGED/TRANSFERRED TO A MEDICARE CERTIFIED LONG TERM CARE HOSPITAL (LTCH)
    """

    C_64 = "64"
    """
    DISCHARGED/TRANSFERRED TO A NURSING FACILITY CERTIFIED UNDER MEDICAID BUT NOT CERTIFIED UNDER MEDICARE
    """

    C_65 = "65"
    """
    DISCHARGED/TRANSFERRED TO A PSYCHIATRIC HOSPITAL OR PSYCHIATRIC DISTINCT PART UNIT OF A HOSPITAL
    """

    C_66 = "66"
    """
    DISCHARGED/TRANSFERRED TO A CRITICAL ACCESS HOSPITAL (CAH)
    """

    C_69 = "69"
    """
    DISCHARGED/TRANSFERRED TO A DESIGNATED DISASTER ALTERNATE CARE SITE (EFFECTIVE 10/1/13)
    """

    C_70 = "70"
    """
    DISCHARGED/TRANSFERRED TO ANOTHER TYPE OF HEALTH CARE INSTITUTION NOT DEFINED ELSEWHERE IN THIS CODE LIST
    """

    C_81 = "81"
    """
    DISCHARGED TO HOME OR SELF CARE WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    C_82 = "82"
    """
    DISCHARGED/TRANSFERRED TO A SHORT TERM GENERAL HOSPITAL FOR INPATIENT CARE WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    C_83 = "83"
    """
    DISCHARGED/TRANSFERRED TO A SKILLED NURSING FACILITY (SNF) WITH MEDICARE CERTIFICATION WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    C_84 = "84"
    """
    DISCHARGED/TRANSFERRED TO A FACILITY THAT PROVIDES CUSTODIAL OR SUPPORTIVE CARE WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    C_85 = "85"
    """
    DISCHARGED/TRANSFERRED TO A DESIGNATED CANCER CENTER OR CHILDREN'S HOSPITAL WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    C_86 = "86"
    """
    DISCHARGED/TRANSFERRED TO HOME UNDER CARE OF ORGANIZED HOME HEALTH SERVICE ORGANIZATION IN ANTICIPATION OF COVERED SKILLED CARE WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    C_87 = "87"
    """
    DISCHARGED/TRANSFERRED TO COURT/LAW ENFORCEMENT WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    C_88 = "88"
    """
    DISCHARGED/TRANSFERRED TO A FEDERAL HEALTH CARE FACILITY WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    C_89 = "89"
    """
    DISCHARGED/TRANSFERRED TO A HOSPITAL-BASED MEDICARE APPROVED SWING BED WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    C_90 = "90"
    """
    DISCHARGED/TRANSFERRED TO AN INPATIENT REHABILITATION FACILITY (IRF) INCLUDING REHABILITATION DISTINCT PART UNITS OF A HOSPITAL WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    C_91 = "91"
    """
    DISCHARGED/TRANSFERRED TO A MEDICARE CERTIFIED LONG TERM CARE HOSPITAL (LTCH) WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    C_92 = "92"
    """
    DISCHARGED/TRANSFERRED TO A NURSING FACILITY CERTIFIED UNDER MEDICAID BUT NOT CERTIFIED UNDER MEDICARE WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    C_93 = "93"
    """
    DISCHARGED/TRANSFERRED TO A PSYCHIATRIC HOSPITAL OR PSYCHIATRIC DISTINCT PART UNIT OF A HOSPITAL WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    C_94 = "94"
    """
    DISCHARGED/TRANSFERRED TO A CRITICAL ACCESS HOSPITAL (CAH) WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    C_95 = "95"
    """
    DISCHARGED/TRANSFERRED TO ANOTHER TYPE OF HEALTH CARE INSTITUTION NOT DEFINED ELSEWHERE IN THIS CODE LIST WITH A PLANNED ACUTE CARE HOSPITAL INPATIENT READMISSION (EFFECTIVE 10/1/13)
    """

    _UNKNOWN = "__PATIENTDISCHARGESTATUSCODE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "PatientDischargeStatusCode":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        c_01: typing.Callable[[], T_Result],
        c_02: typing.Callable[[], T_Result],
        c_03: typing.Callable[[], T_Result],
        c_04: typing.Callable[[], T_Result],
        c_05: typing.Callable[[], T_Result],
        c_06: typing.Callable[[], T_Result],
        c_07: typing.Callable[[], T_Result],
        c_09: typing.Callable[[], T_Result],
        c_20: typing.Callable[[], T_Result],
        c_21: typing.Callable[[], T_Result],
        c_30: typing.Callable[[], T_Result],
        c_40: typing.Callable[[], T_Result],
        c_41: typing.Callable[[], T_Result],
        c_42: typing.Callable[[], T_Result],
        c_43: typing.Callable[[], T_Result],
        c_50: typing.Callable[[], T_Result],
        c_51: typing.Callable[[], T_Result],
        c_61: typing.Callable[[], T_Result],
        c_62: typing.Callable[[], T_Result],
        c_63: typing.Callable[[], T_Result],
        c_64: typing.Callable[[], T_Result],
        c_65: typing.Callable[[], T_Result],
        c_66: typing.Callable[[], T_Result],
        c_69: typing.Callable[[], T_Result],
        c_70: typing.Callable[[], T_Result],
        c_81: typing.Callable[[], T_Result],
        c_82: typing.Callable[[], T_Result],
        c_83: typing.Callable[[], T_Result],
        c_84: typing.Callable[[], T_Result],
        c_85: typing.Callable[[], T_Result],
        c_86: typing.Callable[[], T_Result],
        c_87: typing.Callable[[], T_Result],
        c_88: typing.Callable[[], T_Result],
        c_89: typing.Callable[[], T_Result],
        c_90: typing.Callable[[], T_Result],
        c_91: typing.Callable[[], T_Result],
        c_92: typing.Callable[[], T_Result],
        c_93: typing.Callable[[], T_Result],
        c_94: typing.Callable[[], T_Result],
        c_95: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is PatientDischargeStatusCode.C_01:
            return c_01()
        if self is PatientDischargeStatusCode.C_02:
            return c_02()
        if self is PatientDischargeStatusCode.C_03:
            return c_03()
        if self is PatientDischargeStatusCode.C_04:
            return c_04()
        if self is PatientDischargeStatusCode.C_05:
            return c_05()
        if self is PatientDischargeStatusCode.C_06:
            return c_06()
        if self is PatientDischargeStatusCode.C_07:
            return c_07()
        if self is PatientDischargeStatusCode.C_09:
            return c_09()
        if self is PatientDischargeStatusCode.C_20:
            return c_20()
        if self is PatientDischargeStatusCode.C_21:
            return c_21()
        if self is PatientDischargeStatusCode.C_30:
            return c_30()
        if self is PatientDischargeStatusCode.C_40:
            return c_40()
        if self is PatientDischargeStatusCode.C_41:
            return c_41()
        if self is PatientDischargeStatusCode.C_42:
            return c_42()
        if self is PatientDischargeStatusCode.C_43:
            return c_43()
        if self is PatientDischargeStatusCode.C_50:
            return c_50()
        if self is PatientDischargeStatusCode.C_51:
            return c_51()
        if self is PatientDischargeStatusCode.C_61:
            return c_61()
        if self is PatientDischargeStatusCode.C_62:
            return c_62()
        if self is PatientDischargeStatusCode.C_63:
            return c_63()
        if self is PatientDischargeStatusCode.C_64:
            return c_64()
        if self is PatientDischargeStatusCode.C_65:
            return c_65()
        if self is PatientDischargeStatusCode.C_66:
            return c_66()
        if self is PatientDischargeStatusCode.C_69:
            return c_69()
        if self is PatientDischargeStatusCode.C_70:
            return c_70()
        if self is PatientDischargeStatusCode.C_81:
            return c_81()
        if self is PatientDischargeStatusCode.C_82:
            return c_82()
        if self is PatientDischargeStatusCode.C_83:
            return c_83()
        if self is PatientDischargeStatusCode.C_84:
            return c_84()
        if self is PatientDischargeStatusCode.C_85:
            return c_85()
        if self is PatientDischargeStatusCode.C_86:
            return c_86()
        if self is PatientDischargeStatusCode.C_87:
            return c_87()
        if self is PatientDischargeStatusCode.C_88:
            return c_88()
        if self is PatientDischargeStatusCode.C_89:
            return c_89()
        if self is PatientDischargeStatusCode.C_90:
            return c_90()
        if self is PatientDischargeStatusCode.C_91:
            return c_91()
        if self is PatientDischargeStatusCode.C_92:
            return c_92()
        if self is PatientDischargeStatusCode.C_93:
            return c_93()
        if self is PatientDischargeStatusCode.C_94:
            return c_94()
        if self is PatientDischargeStatusCode.C_95:
            return c_95()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AuthorizedSignatory,
        AuthorizedSignatoryUpdate,
        AuthorizedSignatoryUpdate_Remove,
        AuthorizedSignatoryUpdate_Set,
        Contract,
        ContractBase,
        ContractId,
        ContractInvalidExpirationDateError,
        ContractIsLinkedToFeeScheduleError,
        ContractSortField,
        ContractStatus,
        ContractWithProviders,
        ContractingProviderId,
        ContractsPage,
        DateUpdate,
        DateUpdate_Remove,
        DateUpdate_Set,
        InsuranceTypes,
        InsuranceTypes_AllApply,
        InsuranceTypes_NoneApply,
        InsuranceTypes_TheseApply,
        RegionsUpdate,
        RegionsUpdate_Remove,
        RegionsUpdate_Set,
        RenderingProviderid,
    )
    from .errors import ContractInvalidExpirationDateHttpError, ContractIsLinkedToFeeScheduleHttpError
_dynamic_imports: typing.Dict[str, str] = {
    "AuthorizedSignatory": ".types",
    "AuthorizedSignatoryUpdate": ".types",
    "AuthorizedSignatoryUpdate_Remove": ".types",
    "AuthorizedSignatoryUpdate_Set": ".types",
    "Contract": ".types",
    "ContractBase": ".types",
    "ContractId": ".types",
    "ContractInvalidExpirationDateError": ".types",
    "ContractInvalidExpirationDateHttpError": ".errors",
    "ContractIsLinkedToFeeScheduleError": ".types",
    "ContractIsLinkedToFeeScheduleHttpError": ".errors",
    "ContractSortField": ".types",
    "ContractStatus": ".types",
    "ContractWithProviders": ".types",
    "ContractingProviderId": ".types",
    "ContractsPage": ".types",
    "DateUpdate": ".types",
    "DateUpdate_Remove": ".types",
    "DateUpdate_Set": ".types",
    "InsuranceTypes": ".types",
    "InsuranceTypes_AllApply": ".types",
    "InsuranceTypes_NoneApply": ".types",
    "InsuranceTypes_TheseApply": ".types",
    "RegionsUpdate": ".types",
    "RegionsUpdate_Remove": ".types",
    "RegionsUpdate_Set": ".types",
    "RenderingProviderid": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AuthorizedSignatory",
    "AuthorizedSignatoryUpdate",
    "AuthorizedSignatoryUpdate_Remove",
    "AuthorizedSignatoryUpdate_Set",
    "Contract",
    "ContractBase",
    "ContractId",
    "ContractInvalidExpirationDateError",
    "ContractInvalidExpirationDateHttpError",
    "ContractIsLinkedToFeeScheduleError",
    "ContractIsLinkedToFeeScheduleHttpError",
    "ContractSortField",
    "ContractStatus",
    "ContractWithProviders",
    "ContractingProviderId",
    "ContractsPage",
    "DateUpdate",
    "DateUpdate_Remove",
    "DateUpdate_Set",
    "InsuranceTypes",
    "InsuranceTypes_AllApply",
    "InsuranceTypes_NoneApply",
    "InsuranceTypes_TheseApply",
    "RegionsUpdate",
    "RegionsUpdate_Remove",
    "RegionsUpdate_Set",
    "RenderingProviderid",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.clearinghouse import Clearinghouse
from .....commons.types.street_address_long_zip import StreetAddressLongZip
from .clearinghouse_payer_info import ClearinghousePayerInfo
from .payer_category import PayerCategory
from .payer_uuid import PayerUuid
from .primary_payer_ids import PrimaryPayerIds


class Payer(UniversalBaseModel):
    payer_uuid: PayerUuid = pydantic.Field()
    """
    Auto-generated ID set on creation.
    """

    payer_ids: PrimaryPayerIds = pydantic.Field()
    """
    The primary national payer IDs of the payer.
    """

    payer_name: str = pydantic.Field()
    """
    The primary display name of the payer.
    """

    payer_category: typing.Optional[PayerCategory] = pydantic.Field(default=None)
    """
    The category of the payer.
    """

    alternate_payer_names: typing.List[str] = pydantic.Field()
    """
    The alternate display names of the payer.
    """

    clearinghouse_payer_info: typing.Dict[Clearinghouse, ClearinghousePayerInfo]
    street_address: typing.Optional[StreetAddressLongZip] = None
    alternate_payer_addresses: typing.List[StreetAddressLongZip]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class ValueCode(enum.StrEnum):
    C_01_MONEY = "01"
    """
    Most Common Semi-private Rate
    To provide for the recording of hospital’s most common semi-private rate.
    """

    C_02_MONEY = "02"
    """
    Hospital has no Semi-private Rooms
    Entering this code requires $0.00 amount.
    """

    C_04_MONEY = "04"
    """
    Professional Component Charges which are Combined Billed
    Code indicates the amount shown is the sum of technical and professional charges, which are combined billed. Medicare uses this information in internal processes and in the CMS notice of utilization sent to the patient to explain that Part B coinsurance applies to the professional component.
    """

    C_05_MONEY = "05"
    """
    Professional Component Included in Charges and also Billed Separate to Carrier
    Amount shown is the combined billed charges (technical and professional); however the provider is submitting a separate professional bill to the health plan. For use on Medicare or TRICARE bills and all Medicaid bills if state specifies need for this information.
    """

    C_06_MONEY = "06"
    """
    Blood Deductible
    Total cash blood deductible. If appropriate, enter Medicare Part A or Part B blood deductible amount. (To report other than the blood deductible, that is to report the program deductible, see Value Codes (FL39-FL41) A1, B1, and C1.)
    """

    C_08_MONEY = "08"
    """
    Life Time Reserve Amount in the First Calendar Year
    Lifetime reserve amount charged in the year of admission. Note: For Medicare, use this code only for Part A bills. For Part B Coinsurance use Value Codes (FL39-41) A2, B2, and C2).
    """

    C_09_MONEY = "09"
    """
    Coinsurance Amount in the First Calendar Year
    Coinsurance amounts, charged in the year of admission.
    """

    C_10_MONEY = "10"
    """
    Lifetime Reserve Amount in the Second Calendar Year
    Lifetime reserve amount charged in the year of discharge where the bill spans two calendar years.
    """

    C_11_MONEY = "11"
    """
    Coinsurance Amount in the Second Calendar Year
    Coinsurance amount charged in the year of discharge where the inpatient bill spans two calendar years.
    """

    C_12_MONEY = "12"
    """
    Working Aged Beneficiary/Spouse with Employer Group Health Plan
    Amount shown reflects that portion of a payment from a higher priority employer group health insurance made on behalf of an aged beneficiary. For Medicare purposes the provider is billing Medicare as the secondary, payer (based on MSP development) for covered services on this bill.
    """

    C_13_MONEY = "13"
    """
    ESRD Beneficiary in a Medicare Coordination Period with an Employer Group Health Plan
    Amount shown is that portion of a payment from a higher priority employer group health insurance payment made on behalf of an ESRD beneficiary that the provider is applying to Medicare covered services on this bill.
    """

    C_14_MONEY = "14"
    """
    No-Fault, Including Auto/Other
    Amount shown is that portion from a higher priority no-fault insurance, including auto/other made on behalf of the patient or insured. For Medicare beneficiaries, the provider should apply this amount to the Medicare covered services on this bill.
    """

    C_15_MONEY = "15"
    """
    Worker’s Compensation
    Amount shown is that portion of a payment from a higher priority worker’s compensation insurance made on behalf of the patient or insured. For Medicare beneficiaries the provider should apply this amount to Medicare covered services on this bill.
    """

    C_16_MONEY = "16"
    """
    PHS, or Other Federal Agency
    Amount shown is that portion of a payment from a higher priority Public Health Service or the Federal Agency made on behalf of a Medicare beneficiary that the provider is applying to Medicare covered services on this bill.
    """

    C_21_MONEY = "21"
    """
    Catastrophic
    Catastrophic Medicaid-eligibility and coverage requirements determined at the state level.
    """

    C_22_MONEY = "22"
    """
    Surplus Income
    Surplus (or excess) income as designated by Medicaid eligibility requirements determined at the state level.
    """

    C_23_MONEY = "23"
    """
    Recurring Monthly Income
    Monthly income as designated by Medicaid-eligibility requirements determined at the state level.
    """

    C_24_NUM = "24"
    """
    Medicaid Rate Code
    Code indicating the payment or reimbursement rate designated by Medicaid at the state level.
    """

    C_25_MONEY = "25"
    """
    Offset to the Patient-Payment Amount - Prescription Drugs
    Prescription drugs paid for out of a long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_26_MONEY = "26"
    """
    Offset to the Patient-Payment Amount - Hearing and Ear Services
    Hearing and ear services paid for out of a long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_27_MONEY = "27"
    """
    Offset to the Patient-Payment Amount - Vision and Eye Services
    Vision and eye services paid for out of a long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_28_MONEY = "28"
    """
    Offset to the Patient-Payment Amount - Dental Services
    Dental services paid for out of a long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_29_MONEY = "29"
    """
    Offset to the Patient-Payment Amount - Chiropractic Services
    Chiropractic services paid for out of a long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_30_MONEY = "30"
    """
    Preadmission Testing
    This code reflects charges for preadmission outpatient diagnostic services in preparation for a previously scheduled admission.
    """

    C_31_MONEY = "31"
    """
    Patient Liability Amount
    Approved amount to charge the beneficiary for non-covered accommodations, diagnostic procedures or treatments.
    """

    C_32_NUM = "32"
    """
    Multiple Patient Ambulance Transport
    When more than one patient is transported in a single ambulance trip, report the total number of patients transported.
    """

    C_33_MONEY = "33"
    """
    Offset to the Patient-Payment Amount - Podiatric Services
    Podiatric services paid for out of a long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_34_MONEY = "34"
    """
    Offset to the Patient-Payment Amount - Other Medical Services
    Other medical services paid for out of a long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_35_MONEY = "35"
    """
    Offset to the Patient-Payment Amount - Health Insurance Premiums
    Health insurance premiums paid for out of long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_37_NUM = "37"
    """
    Units of Blood Furnished
    The total number of units of whole blood or packed red cells furnished to the patient, regardless of whether the hospital charges for blood or not.
    """

    C_38_NUM = "38"
    """
    Blood Deductible Units
    The number of unreplaced deductible units of packed red cells furnished for which the patient is responsible. If all deductible units furnished have been replaced, no entry is made.
    """

    C_39_NUM = "39"
    """
    Units of Blood Replaced
    The total number of units of whole blood or packed red cells furnished to the patient that have been replaced by or on behalf of the patient.
    """

    C_40_MONEY = "40"
    """
    New Coverage not Implemented by HMO (for inpatient service only)
    Amount shown is for inpatient charges covered by the HMO. (Use this code when the bill includes inpatient charges for newly covered services that are not paid by the HMO.) Note: Condition Codes 04 and 78 should also be reported.
    """

    C_41_MONEY = "41"
    """
    Black Lung
    Code indicates the amount shown is that portion of a higher priority Black Lung (federal program) payment made on behalf of a Medicare beneficiary. Note: The reporting of zero indicates the provider is claiming a conditional payment because there has been a substantial delay in payment from the Black Lung Program.
    """

    C_42_MONEY = "42"
    """
    VA or PACE
    Code indicates the amount shown is that portion of a higher priority VA or PACE payment made on behalf of a Medicare beneficiary and that you are applying to Medicare as secondary payer for covered Medicare services on this claim.
    """

    C_43_MONEY = "43"
    """
    Disabled Beneficiary Under Age 65 with LGHP
    Code indicates the amount shown is that portion of a higher priority LGHP payment made on behalf of a disabled beneficiary that you are applying to covered Medicare charges on this bill.
    """

    C_44_MONEY = "44"
    """
    Amount Provider Agreed to Accept from Primary Payer when this Amount is less than Charges but Higher than Payment Received
    Report the amount the provider was obligated to accept from a primary payer when the amount is less than charges but higher than or equal to the payment received. Secondary payment may be due. Note: The following value codes report the actual amounts paid: 12- 16, 41-43, and 47. Value Code 44 should always be equal to, or, greater than the amounts indicated in the value codes indicated immediately above.
    """

    C_45_NUM = "45"
    """
    Accident Hour
    The hour when the accident occurred that necessitated medical treatment. 00 12:00 - 12:59 (Midnight), 13 01:00 - 01:59, 01 01:00 - 01:59, 14 02:00 - 02:59, 02 02:00 - 02:59, 15 03:00 - 03:59, 03 03:00 - 03:59, 16 04:00 - 04:59, 04 04:00 - 04:59, 17 05:00 - 05:59, 05 05:00 - 05:59, 18 06:00 - 06:59, 06 06:00 - 06:59, 19 07:00 - 07:59, 07 07:00 - 07:59, 20 08:00 - 08:59, 08 08:00 - 08:59, 21 09:00 - 09:59, 09 09:00 - 09:59, 22 10:00 - 10:59, 10 10:00 - 10:59, 23 11:00 - 11:59, 11 11:00 - 11:59, 99 Unknown, 12 12:00 - 12:59 (Noon)
    """

    C_46_NUM = "46"
    """
    Number of Grace Days
    Follows the QIO determination. This is the number of days determined by the QIO (medical necessity reviewer) as necessary to arrange for the patient’s post-discharge care.
    """

    C_47_MONEY = "47"
    """
    Any Liability Insurance
    Amount shown is that portion from a higher priority liability insurance made on behalf of a Medicare beneficiary that the provider is applying to Medicare covered services on this bill. Enter zero in the amount field if you are claiming a conditional payment.
    """

    C_48_NUM = "48"
    """
    Hemoglobin Reading
    The most recent hemoglobin reading taken before the start of this billing period. For patients just starting, use the most recent value prior to the onset if treatment. The reading is a 3-byte numeric element (XX.X). Results exceeding 3-position numeric elements (e.g., 10.50) are reported as 10.5.
    """

    C_49_NUM = "49"
    """
    Hematocrit Reading
    The most recent hematocrit reading taken before the start of this billing period. For patients just starting, use the most recent value prior to the onset if treatment. The reading is a 3-byte numeric element (XX.X). Results exceeding 3-position numeric elements (e.g., l0.50) are reported as 10.5.
    """

    C_50_NUM = "50"
    """
    Physical Therapy Visits
    Report the number of physical therapy visits provided from the onset of treatment from this billing provider through this billing period.
    """

    C_51_NUM = "51"
    """
    Occupational Therapy Visits
    Report the number of occupational therapy visits provided from the onset of treatment from this billing provider) through this billing period.
    """

    C_52_NUM = "52"
    """
    Speech Therapy Visits
    Report the number of speech therapy visits provided from the onset of treatment by this billing provider through this period.
    """

    C_53_NUM = "53"
    """
    Cardiac Rehab Visits
    The number of cardiac rehabilitation visits from the onset of treatment from the billing provider through this billing period.
    """

    C_54_NUM = "54"
    """
    Newborn Birth Weight in Grams
    Actual birth weight or weight at time of admission for an extramural birth. Required on all claims with Priority (Type) of Admission of 4 and on other claims as required by state law.
    """

    C_55_MONEY = "55"
    """
    Eligibility Threshold for Charity Care
    The amount at which a health care facility determines the eligibility threshold for charity care.
    """

    C_56_NUM = "56"
    """
    Skilled Nurse - Home Visit Hours (HHA only)
    The number of home visit hours of skilled nursing provided during the billing period. Count only hours spent in the home.  Exclude travel time. Report in whole hours, rounded to the nearest whole hour.
    """

    C_57_NUM = "57"
    """
    Home Health Aide - Home Visit Hours (HHA only)
    The number of hours of home health aide services provided during the billing period.  Count only hours spent in the home. Exclude travel time. Report in whole hours, rounded to the nearest whole hour.
    """

    C_58_NUM = "58"
    """
    Arterial Blood Gas (P02)
    Arterial blood gas value at beginning of each reporting period for oxygen therapy. This value or the value in Value Code 59 will be required on the initial bill for oxygen therapy and on the fourth month’s bill.  Report two digits rounded to the nearest whole number. Example: A value of 56.5 should be reported as 57.
    """

    C_59_NUM = "59"
    """
    Oxygen Saturation Oximetry
    Oxygen percent saturation at the beginning of each reporting period for oxygen therapy. This value or the value in Value Code 58 will be required on the initial bill for oxygen therapy and on the fourth month’s bill.  Report two digits rounded to the nearest whole percent. Example: 93.5 percent should be reported as 0.94. A value of 100 percent would be reported as 1.
    """

    C_60_NUM = "60"
    """
    HHA Branch MSA
    MSA in which HHA branch is located (Report MSA when branch location is different than the HHA’s.
    """

    C_61_NUM = "61"
    """
    Place of Residence where Service is Furnished (HHA and Hospice)
    MSA or Core Based Statistical Area (CBSA) number (or rural state code) of the place of residence where the home health or hospice service is delivered.
    """

    C_66_MONEY = "66"
    """
    Medicaid Spend Down Amount
    The dollar amount that was used to meet the recipient’s spend down liability for this claim.
    """

    C_67_NUM = "67"
    """
    Peritoneal Dialysis
    The number of hours of peritoneal dialysis provided during the billing period.  Count only the hours spent in the home. Exclude travel time. Report in whole hours, rounded to the nearest whole hour.
    """

    C_68_NUM = "68"
    """
    EPO-Drug
    Number of units of EPO administered and/or supplied relating to the billing period. Report amount in whole units.
    """

    C_69_NUM = "69"
    """
    State Charity Care Percent
    Code indicates the percentage of charity care eligibility for the patient.  For example, a rate of 10.5% is shown as: 0 . 1 0 5
    """

    C_80_NUM = "80"
    """
    Covered Days
    The number of days covered by the primary payer as qualified by the payer.
    """

    C_81_NUM = "81"
    """
    Non-covered Days
    Days of care not covered by the primary payer.
    """

    C_82_NUM = "82"
    """
    Co-insurance Days
    The inpatient Medicare days occurring after the 60th day and before the 91st day or inpatient SNF/Swing Bed days occurring after the 20th and before the 101st day in a single spell of illness.
    """

    C_83_NUM = "83"
    """
    Lifetime Reserve Days
    Under Medicare, each beneficiary has a lifetime reserve of 60 additional days of inpatient hospital services after using 90 days of inpatient hospital services during a spell of illness.
    """

    C_84_NUM = "84"
    """
    Shorter Duration Hemodialysis
    The number of sessions per week as specified in the patient’s plan of care for hemodialysis that is shorter in duration (Revenue Code 0826) than conventional sessions (reported under Revenue Code 0821).
    """

    C_85_NUM = "85"
    """
    County where Service is Rendered (Effective 1/1/19)
    Report the Federal Information Processing Standards (FIPS) state and county codes when required by law or regulation with no space between the state code and the county code.
    """

    C_87_MONEY = "87"
    """
    Gene Therapy Invoice Cost (Effective 4/1/20)
    Invoice/acquisition cost of modified biologics. For use with Revenue Category 0892.
    """

    C_89_MONEY = "89"
    """
    Allogeneic Stem Cell Transplant – Total All-inclusive Donor Charges (Effective 7/1/20)
    Report on the recipient’s stem cell transplant claim the total of all donor charges, including charges billed on separately submitted claims.
    """

    C_90_MONEY = "90"
    """
    Cell Therapy Invoice Cost (Effective 4/1/20)
    Invoice/acquisition cost of modified biologics. For use with Revenue Category 0891.
    """

    C_91_MONEY = "91"
    """
    Charges for Kidney Acquisition (Effective 10/1/21)
    Used by providers to identify charges for kidney acquisitions when mandated by state or federal law or regulation.
    """

    CA_0_NUM = "A0"
    """
    Special ZIP Code Reporting
    Five digit ZIP Code of the location from which the beneficiary is initially placed on board the ambulance.
    """

    CA_1_MONEY = "A1"
    """
    Deductible Payer A
    The amount assumed by the provider to be applied to the patient’s policy/program deductible amount involving the indicated payer. (Note: Report Medicare blood deductibles under Value Code 6.)
    """

    CA_2_MONEY = "A2"
    """
    Coinsurance Payer A
    The amount assumed by the provider to be applied toward the patient’s coinsurance amount involving the indicated payer. (Note: For Medicare, use this code only for reporting Part B coinsurance amounts. For Part A coinsurance amounts use Value Codes 8-11.)
    """

    CA_3_MONEY = "A3"
    """
    Estimated Responsibility Payer A
    The amount estimated by the provider to be paid by the indicated payer; it is not the actual payment.
    """

    CA_4_MONEY = "A4"
    """
    Covered Self-administrable Drugs - Emergency
    The covered charge amount for self-administrable drugs administered to the patient in an emergency situation (e.g., diabetic coma). For use with Revenue Code 0637.
    """

    CA_5_MONEY = "A5"
    """
    Covered Self-administrable Drugs - not Self-administrable in the Form and Situation Furnished to Patient
    The amount included in covered charges for self-administrable drugs administered to the patient because the drug was not self-administrable in the form and situation in which it was furnished to the patient. For use with Revenue Code 0637.
    """

    CA_6_MONEY = "A6"
    """
    Covered Self-administrable Drugs - Diagnostic Study and Other
    The amount included in covered charges for self-administrable drugs administered to the patient because the drug was necessary for diagnostic study or other reason (e.g., the drug is specifically covered by the payer).
    """

    CA_7_MONEY = "A7"
    """
    Co-payment Payer A
    The amount assumed by the provider to be applied toward the patient’s co-payment amount involving the indicated payer.
    """

    CA_8_NUM = "A8"
    """
    Patient Weight
    Weight of patient in kilograms. Report this data only when the health plan has a predefined change in reimbursement that is affected by weight. For newborns, use Value Code 54
    """

    CA_9_NUM = "A9"
    """
    Patient Height
    Height of patient in centimeters. Report this data only when the health plan has a predefined change in reimbursement that is affected by height.
    """

    CAA_MONEY = "AA"
    """
    Regulatory Surcharges, Assessments, Allowances or Health Care Related Taxes Payer A
    The amount of regulatory surcharges, assessments, allowances or health care related taxes pertaining to the indicated payer.
    """

    CAB_MONEY = "AB"
    """
    Other Assessments or Allowances (e.g., Medical Education) Payer A
    The amount of other assessments or allowances (e.g., medical education) pertaining to the indicated payer.
    """

    CB_1_MONEY = "B1"
    """
    Deductible Payer B
    The amount assumed by the provider to be applied to the patient’s policy/program deductible amount involving the indicated payer. (Note: Medicare blood deductibles should be reported under Value Code 6.)
    """

    CB_2_MONEY = "B2"
    """
    Coinsurance Payer B
    The amount assumed by the provider to be applied toward the patient’s coinsurance amount involving the indicated payer. For Part A coinsurance amounts use Value Codes 8-11.)
    """

    CB_3_MONEY = "B3"
    """
    Estimated Responsibility Payer B
    The amount estimated by the provider to be paid by the indicated payer; it is not the actual payment.
    """

    CB_7_MONEY = "B7"
    """
    Co-payment Payer B
    The amount assumed by the provider to be applied toward the patient’s co-payment amount involving the indicated payer.
    """

    CBA_MONEY = "BA"
    """
    Regulatory Surcharges, Assessments, Allowances or Health Care Related Taxes Payer B
    The amount of regulatory surcharges, assessments, allowances or health care related taxes pertaining to the indicated payer.
    """

    CBB_MONEY = "BB"
    """
    Other Assessments or Allowances (e.g., Medical Education) Payer B
    The amount of other assessments or allowances (e.g., medical education) pertaining to the indicated payer.
    """

    CC_1_MONEY = "C1"
    """
    Deductible Payer C
    The amount assumed by the provider to be applied to the patient’s policy/program deductible amount involving the indicated payer. (Note: Medicare blood deductibles should be reported under Value Code 6.)
    """

    CC_2_MONEY = "C2"
    """
    Coinsurance Payer C
    The amount assumed by the provider to be applied toward the patient’s coinsurance amount involving the indicated payer. For Part A coinsurance amounts use Value Codes 8-11.)
    """

    CC_3_MONEY = "C3"
    """
    Estimated Responsibility Payer C
    The amount estimated by the provider to be paid by the indicated payer; it is not the actual payment.
    """

    CC_7_MONEY = "C7"
    """
    Co-payment Payer C
    The amount assumed by the provider to be applied toward the patient’s co-payment amount involving the indicated payer.
    """

    CCA_MONEY = "CA"
    """
    Regulatory Surcharges, Assessments, Allowances or Health Care Related Taxes Payer C
    The amount of regulatory surcharges, assessments, allowances or health care related taxes pertaining to the indicated payer.
    """

    CCB_MONEY = "CB"
    """
    Other Assessments or Allowances (e.g., Medical Education) Payer C
    The amount of other assessments or allowances (e.g., medical education) pertaining to the indicated payer.
    """

    CD_3_MONEY = "D3"
    """
    Patient Estimated Responsibility
    The amount estimated by the provider to be paid by the indicated patient.
    """

    CD_4_NUM = "D4"
    """
    Clinical Trial Number Assigned by NLM/NIH
    8-digit, numeric National Library of Medicine/ National Institutes of Health assigned clinical trial number.
    """

    CD_5_NUM = "D5"
    """
    Last Kt/V Reading (Effective 7/1/10)
    Result of last Kt/V reading. For in-center hemodialysis patients, this is the last reading taken during the billing period. For peritoneal dialysis patients (and home hemodialysis patients), this may be before the current billing period but should be within 4 months of the date of service.
    """

    CD_6_NUM = "D6"
    """
    Total Number of Minutes of Dialysis Provided During the Billing Period. (Effective 1/1/21)
    The machine reported number of minutes (rounded to the nearest whole minute) of dialysis treatment time.  The total count includes only the minutes spent dialyzing. The duration begins when the treatment starts and ends when the treatment is complete. The units reported must exceed 1.  For Medicare ESRD claims. See Medicare manual for further instructions on the use of this code along with other related UB codes.
    """

    CFC_MONEY = "FC"
    """
    Patient Paid Amount
    The amount the provider has received from the patient toward payment of this bill. (Effective 7/1/08)
    """

    CFD_MONEY = "FD"
    """
    Credit Received from the Manufacturer for a Medical Device
    The amount the provider has received from a medical device manufacturer as credit for a medical device. (Effective 7/1/15)
    """

    CG_8_NUM = "G8"
    """
    Facility where Inpatient Hospice Service is Delivered
    MSA or Core Based Statistical Area (CBSA) number (or rural state code) of the facility where inpatient hospice service is delivered.
    """

    CP_1_NUM = "P1"
    """
    Heart Rate (Effective 7/1/19)
    FOR PUBLIC HEALTH DATAREPORTING ONLY when required by state or federal law or regulations. Code indicates patient heart rate in beats per minute taken upon arrival for treatment.
    """

    CP_2_NUM = "P2"
    """
    Blood Pressure – Systolic (Effective 7/1/19)
    FOR PUBLIC HEALTH DATA REPORTING ONLY when required by state or federal law or regulations. Code indicates patient systolic blood pressure in mg/dl, taken upon arrival for treatment.
    """

    CP_3_NUM = "P3"
    """
    Blood Pressure – Diastolic (Effective 7/1/19)
    FOR PUBLIC HEALTH DATAREPORTING ONLY when required by state or federal law or regulations. Code indicates patient diastolic blood pressure in mg/dl, taken upon arrival for treatment.
    """

    CY_1_MONEY = "Y1"
    """
    Part A Demonstration Payment
    This is the portion of the payment designated as reimbursement for Part A services under the demonstration/model.
    """

    CY_2_MONEY = "Y2"
    """
    Part B Demonstration Payment
    This is the portion of the payment designated as reimbursement for Part B services under the demonstration/model. No deductible or coinsurance has been applied.
    """

    CY_3_MONEY = "Y3"
    """
    Part B Coinsurance
    This is the amount of Part B coinsurance applied by the A/B MAC to this demonstration/model claim.
    """

    CY_4_MONEY = "Y4"
    """
    Conventional Provider Payment
    This is the amount Medicare would have reimbursed the provider for Part A services if there had been no demonstration/model.
    """

    CY_5_MONEY = "Y5"
    """
    Part B Deductible (Effective 4/1/13)
    This is the amount of Part B deductible applied by the A/B MAC to this demonstration/model claim.
    """

    _UNKNOWN = "__VALUECODE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ValueCode":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        c_01_money: typing.Callable[[], T_Result],
        c_02_money: typing.Callable[[], T_Result],
        c_04_money: typing.Callable[[], T_Result],
        c_05_money: typing.Callable[[], T_Result],
        c_06_money: typing.Callable[[], T_Result],
        c_08_money: typing.Callable[[], T_Result],
        c_09_money: typing.Callable[[], T_Result],
        c_10_money: typing.Callable[[], T_Result],
        c_11_money: typing.Callable[[], T_Result],
        c_12_money: typing.Callable[[], T_Result],
        c_13_money: typing.Callable[[], T_Result],
        c_14_money: typing.Callable[[], T_Result],
        c_15_money: typing.Callable[[], T_Result],
        c_16_money: typing.Callable[[], T_Result],
        c_21_money: typing.Callable[[], T_Result],
        c_22_money: typing.Callable[[], T_Result],
        c_23_money: typing.Callable[[], T_Result],
        c_24_num: typing.Callable[[], T_Result],
        c_25_money: typing.Callable[[], T_Result],
        c_26_money: typing.Callable[[], T_Result],
        c_27_money: typing.Callable[[], T_Result],
        c_28_money: typing.Callable[[], T_Result],
        c_29_money: typing.Callable[[], T_Result],
        c_30_money: typing.Callable[[], T_Result],
        c_31_money: typing.Callable[[], T_Result],
        c_32_num: typing.Callable[[], T_Result],
        c_33_money: typing.Callable[[], T_Result],
        c_34_money: typing.Callable[[], T_Result],
        c_35_money: typing.Callable[[], T_Result],
        c_37_num: typing.Callable[[], T_Result],
        c_38_num: typing.Callable[[], T_Result],
        c_39_num: typing.Callable[[], T_Result],
        c_40_money: typing.Callable[[], T_Result],
        c_41_money: typing.Callable[[], T_Result],
        c_42_money: typing.Callable[[], T_Result],
        c_43_money: typing.Callable[[], T_Result],
        c_44_money: typing.Callable[[], T_Result],
        c_45_num: typing.Callable[[], T_Result],
        c_46_num: typing.Callable[[], T_Result],
        c_47_money: typing.Callable[[], T_Result],
        c_48_num: typing.Callable[[], T_Result],
        c_49_num: typing.Callable[[], T_Result],
        c_50_num: typing.Callable[[], T_Result],
        c_51_num: typing.Callable[[], T_Result],
        c_52_num: typing.Callable[[], T_Result],
        c_53_num: typing.Callable[[], T_Result],
        c_54_num: typing.Callable[[], T_Result],
        c_55_money: typing.Callable[[], T_Result],
        c_56_num: typing.Callable[[], T_Result],
        c_57_num: typing.Callable[[], T_Result],
        c_58_num: typing.Callable[[], T_Result],
        c_59_num: typing.Callable[[], T_Result],
        c_60_num: typing.Callable[[], T_Result],
        c_61_num: typing.Callable[[], T_Result],
        c_66_money: typing.Callable[[], T_Result],
        c_67_num: typing.Callable[[], T_Result],
        c_68_num: typing.Callable[[], T_Result],
        c_69_num: typing.Callable[[], T_Result],
        c_80_num: typing.Callable[[], T_Result],
        c_81_num: typing.Callable[[], T_Result],
        c_82_num: typing.Callable[[], T_Result],
        c_83_num: typing.Callable[[], T_Result],
        c_84_num: typing.Callable[[], T_Result],
        c_85_num: typing.Callable[[], T_Result],
        c_87_money: typing.Callable[[], T_Result],
        c_89_money: typing.Callable[[], T_Result],
        c_90_money: typing.Callable[[], T_Result],
        c_91_money: typing.Callable[[], T_Result],
        ca_0_num: typing.Callable[[], T_Result],
        ca_1_money: typing.Callable[[], T_Result],
        ca_2_money: typing.Callable[[], T_Result],
        ca_3_money: typing.Callable[[], T_Result],
        ca_4_money: typing.Callable[[], T_Result],
        ca_5_money: typing.Callable[[], T_Result],
        ca_6_money: typing.Callable[[], T_Result],
        ca_7_money: typing.Callable[[], T_Result],
        ca_8_num: typing.Callable[[], T_Result],
        ca_9_num: typing.Callable[[], T_Result],
        caa_money: typing.Callable[[], T_Result],
        cab_money: typing.Callable[[], T_Result],
        cb_1_money: typing.Callable[[], T_Result],
        cb_2_money: typing.Callable[[], T_Result],
        cb_3_money: typing.Callable[[], T_Result],
        cb_7_money: typing.Callable[[], T_Result],
        cba_money: typing.Callable[[], T_Result],
        cbb_money: typing.Callable[[], T_Result],
        cc_1_money: typing.Callable[[], T_Result],
        cc_2_money: typing.Callable[[], T_Result],
        cc_3_money: typing.Callable[[], T_Result],
        cc_7_money: typing.Callable[[], T_Result],
        cca_money: typing.Callable[[], T_Result],
        ccb_money: typing.Callable[[], T_Result],
        cd_3_money: typing.Callable[[], T_Result],
        cd_4_num: typing.Callable[[], T_Result],
        cd_5_num: typing.Callable[[], T_Result],
        cd_6_num: typing.Callable[[], T_Result],
        cfc_money: typing.Callable[[], T_Result],
        cfd_money: typing.Callable[[], T_Result],
        cg_8_num: typing.Callable[[], T_Result],
        cp_1_num: typing.Callable[[], T_Result],
        cp_2_num: typing.Callable[[], T_Result],
        cp_3_num: typing.Callable[[], T_Result],
        cy_1_money: typing.Callable[[], T_Result],
        cy_2_money: typing.Callable[[], T_Result],
        cy_3_money: typing.Callable[[], T_Result],
        cy_4_money: typing.Callable[[], T_Result],
        cy_5_money: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ValueCode.C_01_MONEY:
            return c_01_money()
        if self is ValueCode.C_02_MONEY:
            return c_02_money()
        if self is ValueCode.C_04_MONEY:
            return c_04_money()
        if self is ValueCode.C_05_MONEY:
            return c_05_money()
        if self is ValueCode.C_06_MONEY:
            return c_06_money()
        if self is ValueCode.C_08_MONEY:
            return c_08_money()
        if self is ValueCode.C_09_MONEY:
            return c_09_money()
        if self is ValueCode.C_10_MONEY:
            return c_10_money()
        if self is ValueCode.C_11_MONEY:
            return c_11_money()
        if self is ValueCode.C_12_MONEY:
            return c_12_money()
        if self is ValueCode.C_13_MONEY:
            return c_13_money()
        if self is ValueCode.C_14_MONEY:
            return c_14_money()
        if self is ValueCode.C_15_MONEY:
            return c_15_money()
        if self is ValueCode.C_16_MONEY:
            return c_16_money()
        if self is ValueCode.C_21_MONEY:
            return c_21_money()
        if self is ValueCode.C_22_MONEY:
            return c_22_money()
        if self is ValueCode.C_23_MONEY:
            return c_23_money()
        if self is ValueCode.C_24_NUM:
            return c_24_num()
        if self is ValueCode.C_25_MONEY:
            return c_25_money()
        if self is ValueCode.C_26_MONEY:
            return c_26_money()
        if self is ValueCode.C_27_MONEY:
            return c_27_money()
        if self is ValueCode.C_28_MONEY:
            return c_28_money()
        if self is ValueCode.C_29_MONEY:
            return c_29_money()
        if self is ValueCode.C_30_MONEY:
            return c_30_money()
        if self is ValueCode.C_31_MONEY:
            return c_31_money()
        if self is ValueCode.C_32_NUM:
            return c_32_num()
        if self is ValueCode.C_33_MONEY:
            return c_33_money()
        if self is ValueCode.C_34_MONEY:
            return c_34_money()
        if self is ValueCode.C_35_MONEY:
            return c_35_money()
        if self is ValueCode.C_37_NUM:
            return c_37_num()
        if self is ValueCode.C_38_NUM:
            return c_38_num()
        if self is ValueCode.C_39_NUM:
            return c_39_num()
        if self is ValueCode.C_40_MONEY:
            return c_40_money()
        if self is ValueCode.C_41_MONEY:
            return c_41_money()
        if self is ValueCode.C_42_MONEY:
            return c_42_money()
        if self is ValueCode.C_43_MONEY:
            return c_43_money()
        if self is ValueCode.C_44_MONEY:
            return c_44_money()
        if self is ValueCode.C_45_NUM:
            return c_45_num()
        if self is ValueCode.C_46_NUM:
            return c_46_num()
        if self is ValueCode.C_47_MONEY:
            return c_47_money()
        if self is ValueCode.C_48_NUM:
            return c_48_num()
        if self is ValueCode.C_49_NUM:
            return c_49_num()
        if self is ValueCode.C_50_NUM:
            return c_50_num()
        if self is ValueCode.C_51_NUM:
            return c_51_num()
        if self is ValueCode.C_52_NUM:
            return c_52_num()
        if self is ValueCode.C_53_NUM:
            return c_53_num()
        if self is ValueCode.C_54_NUM:
            return c_54_num()
        if self is ValueCode.C_55_MONEY:
            return c_55_money()
        if self is ValueCode.C_56_NUM:
            return c_56_num()
        if self is ValueCode.C_57_NUM:
            return c_57_num()
        if self is ValueCode.C_58_NUM:
            return c_58_num()
        if self is ValueCode.C_59_NUM:
            return c_59_num()
        if self is ValueCode.C_60_NUM:
            return c_60_num()
        if self is ValueCode.C_61_NUM:
            return c_61_num()
        if self is ValueCode.C_66_MONEY:
            return c_66_money()
        if self is ValueCode.C_67_NUM:
            return c_67_num()
        if self is ValueCode.C_68_NUM:
            return c_68_num()
        if self is ValueCode.C_69_NUM:
            return c_69_num()
        if self is ValueCode.C_80_NUM:
            return c_80_num()
        if self is ValueCode.C_81_NUM:
            return c_81_num()
        if self is ValueCode.C_82_NUM:
            return c_82_num()
        if self is ValueCode.C_83_NUM:
            return c_83_num()
        if self is ValueCode.C_84_NUM:
            return c_84_num()
        if self is ValueCode.C_85_NUM:
            return c_85_num()
        if self is ValueCode.C_87_MONEY:
            return c_87_money()
        if self is ValueCode.C_89_MONEY:
            return c_89_money()
        if self is ValueCode.C_90_MONEY:
            return c_90_money()
        if self is ValueCode.C_91_MONEY:
            return c_91_money()
        if self is ValueCode.CA_0_NUM:
            return ca_0_num()
        if self is ValueCode.CA_1_MONEY:
            return ca_1_money()
        if self is ValueCode.CA_2_MONEY:
            return ca_2_money()
        if self is ValueCode.CA_3_MONEY:
            return ca_3_money()
        if self is ValueCode.CA_4_MONEY:
            return ca_4_money()
        if self is ValueCode.CA_5_MONEY:
            return ca_5_money()
        if self is ValueCode.CA_6_MONEY:
            return ca_6_money()
        if self is ValueCode.CA_7_MONEY:
            return ca_7_money()
        if self is ValueCode.CA_8_NUM:
            return ca_8_num()
        if self is ValueCode.CA_9_NUM:
            return ca_9_num()
        if self is ValueCode.CAA_MONEY:
            return caa_money()
        if self is ValueCode.CAB_MONEY:
            return cab_money()
        if self is ValueCode.CB_1_MONEY:
            return cb_1_money()
        if self is ValueCode.CB_2_MONEY:
            return cb_2_money()
        if self is ValueCode.CB_3_MONEY:
            return cb_3_money()
        if self is ValueCode.CB_7_MONEY:
            return cb_7_money()
        if self is ValueCode.CBA_MONEY:
            return cba_money()
        if self is ValueCode.CBB_MONEY:
            return cbb_money()
        if self is ValueCode.CC_1_MONEY:
            return cc_1_money()
        if self is ValueCode.CC_2_MONEY:
            return cc_2_money()
        if self is ValueCode.CC_3_MONEY:
            return cc_3_money()
        if self is ValueCode.CC_7_MONEY:
            return cc_7_money()
        if self is ValueCode.CCA_MONEY:
            return cca_money()
        if self is ValueCode.CCB_MONEY:
            return ccb_money()
        if self is ValueCode.CD_3_MONEY:
            return cd_3_money()
        if self is ValueCode.CD_4_NUM:
            return cd_4_num()
        if self is ValueCode.CD_5_NUM:
            return cd_5_num()
        if self is ValueCode.CD_6_NUM:
            return cd_6_num()
        if self is ValueCode.CFC_MONEY:
            return cfc_money()
        if self is ValueCode.CFD_MONEY:
            return cfd_money()
        if self is ValueCode.CG_8_NUM:
            return cg_8_num()
        if self is ValueCode.CP_1_NUM:
            return cp_1_num()
        if self is ValueCode.CP_2_NUM:
            return cp_2_num()
        if self is ValueCode.CP_3_NUM:
            return cp_3_num()
        if self is ValueCode.CY_1_MONEY:
            return cy_1_money()
        if self is ValueCode.CY_2_MONEY:
            return cy_2_money()
        if self is ValueCode.CY_3_MONEY:
            return cy_3_money()
        if self is ValueCode.CY_4_MONEY:
            return cy_4_money()
        if self is ValueCode.CY_5_MONEY:
            return cy_5_money()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class OccurrenceSpanCode(enum.StrEnum):
    C_70 = "70"
    """
    QUALIFYING STAY DATES FOR SNF USE ONLY
    """

    C_71 = "71"
    """
    PRIOR STAY DATES
    """

    C_72 = "72"
    """
    FIRST/LAST VISIT DATES
    """

    C_73 = "73"
    """
    BENEFIT ELIGIBILITY PERIOD
    """

    C_74 = "74"
    """
    NON-COVERED LEVEL OF CARE/LEAVE OF ABSENCE DATES
    """

    C_75 = "75"
    """
    SNF LEVEL OF CARE DATES
    """

    C_76 = "76"
    """
    PATIENT LIABILITY
    """

    C_77 = "77"
    """
    PROVIDER LIABILITY PERIOD
    """

    C_78 = "78"
    """
    SNF PROIR STAY DATES
    """

    C_80 = "80"
    """
    PRIOR SAME-SNF STAY DATES FOR PAYMENT BAN PRUPOSES
    """

    C_81 = "81"
    """
    ANTEPARTUM DAYS AT REDUCED LEVEL OF CARE
    """

    C_82 = "82"
    """
    HOSPITAL AT HOME CARE DATES
    """

    CM_0 = "M0"
    """
    QIO/UR APPROVED STAY DATES - The first and last days that were approved where not all of the stay was approved. (Use when Condition Code C3 is used in Form Locators 18-28.)
    """

    CM_1 = "M1"
    """
    PROVIDER LIABILITY - NO UTILIZATION - Code indicates the from/through dates of a period of noncovered care that is denied due to lack of medical necessity or as custodial care for which the provider is liable. The beneficiary is not charged with utilization. The provider may not collect Part A or Part B deductible or coinsurance from the beneficiary.
    """

    CM_2 = "M2"
    """
    INPATIENT RESPITE DATES - The from/through dates of a period of inpatient respite care.
    """

    CM_3 = "M3"
    """
    ICF LEVEL OF CARE - The from/through dates of a period of intermediate level of care during an inpatient hospital stay.
    """

    CM_4 = "M4"
    """
    RESIDENTIAL LEVEL OF CARE - The from/through dates of a period of residential level of care during an inpatient hospital stay.
    """

    _UNKNOWN = "__OCCURRENCESPANCODE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "OccurrenceSpanCode":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        c_70: typing.Callable[[], T_Result],
        c_71: typing.Callable[[], T_Result],
        c_72: typing.Callable[[], T_Result],
        c_73: typing.Callable[[], T_Result],
        c_74: typing.Callable[[], T_Result],
        c_75: typing.Callable[[], T_Result],
        c_76: typing.Callable[[], T_Result],
        c_77: typing.Callable[[], T_Result],
        c_78: typing.Callable[[], T_Result],
        c_80: typing.Callable[[], T_Result],
        c_81: typing.Callable[[], T_Result],
        c_82: typing.Callable[[], T_Result],
        cm_0: typing.Callable[[], T_Result],
        cm_1: typing.Callable[[], T_Result],
        cm_2: typing.Callable[[], T_Result],
        cm_3: typing.Callable[[], T_Result],
        cm_4: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is OccurrenceSpanCode.C_70:
            return c_70()
        if self is OccurrenceSpanCode.C_71:
            return c_71()
        if self is OccurrenceSpanCode.C_72:
            return c_72()
        if self is OccurrenceSpanCode.C_73:
            return c_73()
        if self is OccurrenceSpanCode.C_74:
            return c_74()
        if self is OccurrenceSpanCode.C_75:
            return c_75()
        if self is OccurrenceSpanCode.C_76:
            return c_76()
        if self is OccurrenceSpanCode.C_77:
            return c_77()
        if self is OccurrenceSpanCode.C_78:
            return c_78()
        if self is OccurrenceSpanCode.C_80:
            return c_80()
        if self is OccurrenceSpanCode.C_81:
            return c_81()
        if self is OccurrenceSpanCode.C_82:
            return c_82()
        if self is OccurrenceSpanCode.CM_0:
            return cm_0()
        if self is OccurrenceSpanCode.CM_1:
            return cm_1()
        if self is OccurrenceSpanCode.CM_2:
            return cm_2()
        if self is OccurrenceSpanCode.CM_3:
            return cm_3()
        if self is OccurrenceSpanCode.CM_4:
            return cm_4()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.organization_id import OrganizationId
from .....commons.types.patient_external_id import PatientExternalId
from .invoice_destination_metadata import InvoiceDestinationMetadata
from .invoice_item_info import InvoiceItemInfo
from .invoice_status import InvoiceStatus


class Invoice(UniversalBaseModel):
    amount_cents: int = pydantic.Field()
    """
    Total monetary amount (in cents) of all Invoice Items
    """

    created_at: dt.datetime
    updated_at: dt.datetime
    organization_id: OrganizationId
    invoice_destination_metadata: InvoiceDestinationMetadata = pydantic.Field()
    """
    Contains all relevant information from the third-party service this invoice was created in
    """

    patient_external_id: PatientExternalId
    note: typing.Optional[str] = None
    due_date: dt.date
    status: InvoiceStatus
    url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Link to the admin view of the invoice in the third-party service
    """

    customer_invoice_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Link to the patient view of the invoice in the third-party service
    """

    items: InvoiceItemInfo = pydantic.Field()
    """
    The InvoiceItem rollup which contains all claim and service line invoice items
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .claim_submission_record_create_optional import ClaimSubmissionRecordCreateOptional


class ExternalClaimSubmissionCreateOptional(UniversalBaseModel):
    """
    Examples
    --------
    import datetime

    from candid.resources.claim_submission.resources.v_1 import (
        ClaimSubmissionRecordCreateOptional,
        ExternalClaimSubmissionCreateOptional,
    )
    from candid.resources.commons import (
        ClaimSubmissionPayerResponsibilityType,
        IntendedSubmissionMedium,
    )
    from candid.resources.x_12.resources.v_1 import TypeOfBillFrequencyCode

    ExternalClaimSubmissionCreateOptional(
        claim_created_at=datetime.datetime.fromisoformat(
            "2023-01-01 12:00:00+00:00",
        ),
        patient_control_number="PATIENT_CONTROL_NUMBER",
        submission_records=[
            ClaimSubmissionRecordCreateOptional(
                submitted_at=datetime.datetime.fromisoformat(
                    "2023-01-01 13:00:00+00:00",
                ),
                claim_frequency_code=TypeOfBillFrequencyCode.C_1,
                payer_responsibility=ClaimSubmissionPayerResponsibilityType.PRIMARY,
                intended_submission_medium=IntendedSubmissionMedium.ELECTRONIC,
            ),
            ClaimSubmissionRecordCreateOptional(
                submitted_at=datetime.datetime.fromisoformat(
                    "2023-01-04 12:00:00+00:00",
                ),
                claim_frequency_code=TypeOfBillFrequencyCode.C_7,
                payer_responsibility=ClaimSubmissionPayerResponsibilityType.PRIMARY,
                intended_submission_medium=IntendedSubmissionMedium.PAPER,
            ),
        ],
    )
    """

    claim_created_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    When the claim was created in the external system.
    """

    patient_control_number: typing.Optional[str] = pydantic.Field(default=None)
    """
    The Patient Control Number sent on the claim to the payer. To guarantee compatibility with all payers, this field must consist
    only of uppercase letters and numbers and be no more than 14 characters long.
    """

    submission_records: typing.List[ClaimSubmissionRecordCreateOptional] = pydantic.Field()
    """
    A successful claim submission record will be created for each value provided.
    An empty list may be provided for cases where the claim originated in an external system but was never submitted to a payer.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .gender import Gender
    from .individual_base import IndividualBase
    from .individual_base_optional import IndividualBaseOptional
    from .individual_id import IndividualId
    from .patient import Patient
    from .patient_base import PatientBase
    from .patient_clinical_trial_info import PatientClinicalTrialInfo
    from .patient_clinical_trial_info_create import PatientClinicalTrialInfoCreate
    from .patient_create import PatientCreate
    from .patient_non_insurance_payer_info import PatientNonInsurancePayerInfo
    from .patient_non_insurance_payer_info_create import PatientNonInsurancePayerInfoCreate
    from .patient_non_insurance_payer_info_create_optional import PatientNonInsurancePayerInfoCreateOptional
    from .patient_update import PatientUpdate
    from .patient_update_with_optional_address import PatientUpdateWithOptionalAddress
    from .subscriber import Subscriber
    from .subscriber_base import SubscriberBase
    from .subscriber_base_optional import SubscriberBaseOptional
    from .subscriber_create import SubscriberCreate
    from .subscriber_create_optional import SubscriberCreateOptional
_dynamic_imports: typing.Dict[str, str] = {
    "Gender": ".gender",
    "IndividualBase": ".individual_base",
    "IndividualBaseOptional": ".individual_base_optional",
    "IndividualId": ".individual_id",
    "Patient": ".patient",
    "PatientBase": ".patient_base",
    "PatientClinicalTrialInfo": ".patient_clinical_trial_info",
    "PatientClinicalTrialInfoCreate": ".patient_clinical_trial_info_create",
    "PatientCreate": ".patient_create",
    "PatientNonInsurancePayerInfo": ".patient_non_insurance_payer_info",
    "PatientNonInsurancePayerInfoCreate": ".patient_non_insurance_payer_info_create",
    "PatientNonInsurancePayerInfoCreateOptional": ".patient_non_insurance_payer_info_create_optional",
    "PatientUpdate": ".patient_update",
    "PatientUpdateWithOptionalAddress": ".patient_update_with_optional_address",
    "Subscriber": ".subscriber",
    "SubscriberBase": ".subscriber_base",
    "SubscriberBaseOptional": ".subscriber_base_optional",
    "SubscriberCreate": ".subscriber_create",
    "SubscriberCreateOptional": ".subscriber_create_optional",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "Gender",
    "IndividualBase",
    "IndividualBaseOptional",
    "IndividualId",
    "Patient",
    "PatientBase",
    "PatientClinicalTrialInfo",
    "PatientClinicalTrialInfoCreate",
    "PatientCreate",
    "PatientNonInsurancePayerInfo",
    "PatientNonInsurancePayerInfoCreate",
    "PatientNonInsurancePayerInfoCreateOptional",
    "PatientUpdate",
    "PatientUpdateWithOptionalAddress",
    "Subscriber",
    "SubscriberBase",
    "SubscriberBaseOptional",
    "SubscriberCreate",
    "SubscriberCreateOptional",
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.claim_id import ClaimId
from .....commons.types.service_line_id import ServiceLineId


class InvoiceItemAttributionCreate_ServiceLineId(UniversalBaseModel):
    value: ServiceLineId
    type: typing.Literal["service_line_id"] = "service_line_id"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True


class InvoiceItemAttributionCreate_ClaimId(UniversalBaseModel):
    value: ClaimId
    type: typing.Literal["claim_id"] = "claim_id"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True


class InvoiceItemAttributionCreate_Unattributed(UniversalBaseModel):
    """
    Points to the claim or service line that this invoice is attributed to
    """

    type: typing.Literal["unattributed"] = "unattributed"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


InvoiceItemAttributionCreate = typing_extensions.Annotated[
    typing.Union[
        InvoiceItemAttributionCreate_ServiceLineId,
        InvoiceItemAttributionCreate_ClaimId,
        InvoiceItemAttributionCreate_Unattributed,
    ],
    pydantic.Field(discriminator="type"),
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .universal_service_identifier import UniversalServiceIdentifier


class Service(UniversalBaseModel):
    universal_service_identifier: typing.Optional[UniversalServiceIdentifier] = pydantic.Field(default=None)
    """
    Contains the code describing the activity type that is being scheduled.
    """

    start_timestamp: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
